<?php
/*
 * @author Klaas Eikelboom  <klaas.eikelboom@civicoop.org>
 * @date 16-Dec-2022
 * @license  GPL-2.0-or-later
 */

namespace Drupal\cmrf_form_processor_display\Plugin\WebformElement;
use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Annotation\WebformElement;
use Drupal\webform\Plugin\WebformElement\WebformMarkupBase;

/**
 *
 * @WebformElement(
 *   id = "cmrf_display",
 *   label = @Translation("CMRF Display"),
 *   description = @Translation("Display only"),
 *   category = @Translation("CMRF"),
 * )
 */
class CMRFDisplay extends WebformMarkupBase  {

  protected function defineDefaultProperties() {
    return [
        'wrapper_attributes' => [],
        'cmrf_display_mode' => 'literal',
        'cmrf_display_text' => '',
        'cmrf_display_atts' => '',
      ] + parent::defineDefaultProperties();
  }

  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $form['cmrf_display'] = [
      '#type' => 'fieldset',
      '#title' => $this->t("CMRF Display settings"),
      'cmrf_display_mode' => [
        '#type' => 'radios',
        '#title' => t('Mode'),
        '#options' => [
          'literal' => t('Literal'),
          'link' => t('Link'),
          'button' => t('Button'),
        ],
      ],
      'cmrf_display_text' => [
        '#type' => 'textfield',
        '#title' => t('Link or Button Text'),
        '#states' => [
          'visible' => [
            ":input[name='properties[cmrf_display_mode]']" => [
              ['value' => 'link'],
              ['value' => 'button'],
            ],
          ],
        ],
      ],
      'cmrf_display_atts' => [
        '#type' => 'textfield',
        '#title' => t('Attributs to style the button'),
        '#states' => [
          'visible' => [
            ":input[name='properties[cmrf_display_mode]']" => ['value' => 'button'],
          ],
        ],
      ],
    ];
    return $form;
  }

}
